/*-----------------------------------------------------------------------*/
/* Low level disk I/O module SKELETON for FatFs     (C)ChaN, 2019        */
/*-----------------------------------------------------------------------*/
/* If a working storage control module is available, it should be        */
/* attached to the FatFs via a glue function rather than modifying it.   */
/* This is an example of glue functions to attach various exsisting      */
/* storage control modules to the FatFs module with a defined API.       */
/*-----------------------------------------------------------------------*/

#include "ff.h"			/* Obtains integer types */
#include "diskio.h"		/* Declarations of disk functions */
#include "diskio_SD.h"
#include "diskio_W25QXX.h"
#include "stdio.h"

/* Definitions of physical drive number for each drive */
#define DEV_W25QXX  0
#define DEV_SD		1


/*-----------------------------------------------------------------------*/
/* Get Drive Status                                                      */
/*-----------------------------------------------------------------------*/

DSTATUS disk_status (
	BYTE pdrv		/* Physical drive nmuber to identify the drive */
)
{
	DSTATUS stat = RES_OK;
	//int result;

	switch (pdrv) {
	case DEV_W25QXX :
		stat = W25QXX_disk_status();
		// translate the reslut code here
		return stat;

	case DEV_SD :
		stat = SD_disk_status();
		// translate the reslut code here
		return stat;

	// case DEV_USB :
	// 	result = USB_disk_status();
	// 	// translate the reslut code here
	// 	return stat;
	}
	return STA_NOINIT;
}



/*-----------------------------------------------------------------------*/
/* Inidialize a Drive                                                    */
/*-----------------------------------------------------------------------*/

DSTATUS disk_initialize (
	BYTE pdrv				/* Physical drive nmuber to identify the drive */
)
{
	DSTATUS stat = RES_OK;
	//int result;

	switch (pdrv) {
	case DEV_W25QXX :
		stat = W25QXX_disk_initialize();
		//printf("W25QXX_disk_initialize:%d\n",stat);
		// translate the reslut code here
		return stat;

	case DEV_SD :
		stat = SD_disk_initialize();
		// translate the reslut code here
		return stat;
	// case DEV_USB :
	// 	result = USB_disk_initialize();
	// 	// translate the reslut code here
	// 	return stat;
	}
	return STA_NOINIT;
}



/*-----------------------------------------------------------------------*/
/* Read Sector(s)                                                        */
/*-----------------------------------------------------------------------*/

DRESULT disk_read (
	BYTE pdrv,		/* Physical drive nmuber to identify the drive */
	BYTE *buff,		/* Data buffer to store read data */
	LBA_t sector,	/* Start sector in LBA */
	UINT count		/* Number of sectors to read */
)
{
	DRESULT res = RES_OK;
	int result = 0;
	switch (pdrv) {
	case DEV_W25QXX :
		// translate the arguments here
		res = W25QXX_disk_read(buff, sector, count);
		// translate the reslut code here
		return res;

	case DEV_SD :
		// translate the arguments here
		res = SD_disk_read(buff, sector, count);
		// translate the reslut code here
		return res;
	// case DEV_USB :
	// 	// translate the arguments here
	// 	result = USB_disk_read(buff, sector, count);
	// 	// translate the reslut code here
	// 	return res;
	}

	return RES_PARERR;
}



/*-----------------------------------------------------------------------*/
/* Write Sector(s)                                                       */
/*-----------------------------------------------------------------------*/

#if FF_FS_READONLY == 0

DRESULT disk_write (
	BYTE pdrv,			/* Physical drive nmuber to identify the drive */
	const BYTE *buff,	/* Data to be written */
	LBA_t sector,		/* Start sector in LBA */
	UINT count			/* Number of sectors to write */
)
{
	DRESULT res = RES_OK;
	//int result;
	switch (pdrv) {
	case DEV_W25QXX :
		// translate the arguments here
		res = W25QXX_disk_write(buff, sector, count);
		// translate the reslut code here
		return res;
	case DEV_SD :
		// translate the arguments here
		res = SD_disk_write(buff, sector, count);
		// translate the reslut code here
		return res;
	// case DEV_USB :
	// 	// translate the arguments here
	// 	result = USB_disk_write(buff, sector, count);
	// 	// translate the reslut code here
	// 	return res;
	}

	return RES_PARERR;
}

#endif


/*-----------------------------------------------------------------------*/
/* Miscellaneous Functions                                               */
/*-----------------------------------------------------------------------*/

DRESULT disk_ioctl (
	BYTE pdrv,		/* Physical drive nmuber (0..) */
	BYTE cmd,		/* Control code */
	void *buff		/* Buffer to send/receive control data */
)
{
	DRESULT res = RES_OK;
	//int result;

	switch (pdrv) {
	case DEV_W25QXX :
		// Process of the command for the RAM drive
		res = W25QXX_disk_ioctl(cmd, buff);
		return res;
	case DEV_SD :
		// Process of the command for the MMC/SD card
		res = SD_disk_ioctl(cmd, buff);
		return res;

	// case DEV_USB :
	// 	// Process of the command the USB drive
	// 	return res;
	}

	return RES_PARERR;
}

//ʱ
//User defined function to give a current time to fatfs module      */
//31-25: Year(0-127 org.1980), 24-21: Month(1-12), 20-16: Day(1-31) */                                                                                                                                                                                                                                          
//15-11: Hour(0-23), 10-5: Minute(0-59), 4-0: Second(0-29 *2) */                                                                                                                                                                                                                                                
DWORD get_fattime (void)
{				 
	return 0;
}
